import {useNavigate, useParams, useSearchParams} from "react-router-dom"
import TrainsTable from "./TrainsTable"
import {useEffect, useState} from "react"
import {Box, Checkbox, FormLabel} from "@mui/material"
import {DateTimePicker} from "@mui/x-date-pickers"
import dayjs from "dayjs"
import {useQuery, useQueryClient} from "@tanstack/react-query"
import AutocompleteStation from "./AutocompleteStation"

function DateTimeSelector({datetime, setDatetime, realtime, setRealtime}) {
  const navigate = useNavigate()

  function onStationSelected(event, station) {
    if (station !== null)
      navigate(`/station/sncf/${station.id}/`)
  }

  return <>
    <Box component="form" display="flex" alignItems="center" sx={{'& .MuiTextField-root': { m: 1, width: '25ch' },}}>
      <FormLabel>
        Changer la gare recherchée :
      </FormLabel>
      <AutocompleteStation onChange={onStationSelected} />
      <FormLabel>
        Modifier la date et l'heure de recherche :
      </FormLabel>
      <DateTimePicker name="date" label="Date" onChange={setDatetime} value={datetime} disabled={realtime} readOnly={realtime} />
      <Checkbox onChange={event => setRealtime(event.target.checked)} checked={realtime} />
      <FormLabel>
        Temps réel
      </FormLabel>
    </Box>
  </>
}

function Station() {
  // eslint-disable-next-line no-unused-vars
  let {theme, stationId} = useParams()
  // eslint-disable-next-line no-unused-vars
  let [searchParams, setSearchParams] = useSearchParams()
  const [realtime, setRealtime] = useState(searchParams.get('realtime') === "1" || false)
  const [datetime, setDatetime] = useState(dayjs(searchParams.get('time') || undefined))
  if ((searchParams.get('realtime') === null || searchParams.get('realtime') === "0")
    && (searchParams.get('time') === null || realtime)) {
    searchParams.set('realtime', "1")
    searchParams.delete("time")
    setRealtime(true)
    window.history.replaceState({}, '', '?' + searchParams.toString())
  }
  else if (datetime.format() !== searchParams.get('time') && !realtime) {
    searchParams.set('time', datetime.format())
    searchParams.set('realtime', "0")
    window.history.replaceState({}, '', '?' + searchParams.toString())
  }

  useQueryClient()
  const stationQuery = useQuery({
    queryKey: ['station', stationId],
    queryFn: () => fetch(`${process.env.REACT_APP_MOTIS_SERVER}/api/v1/stoptimes?stopId=${stationId}&n=1`)
      .then(response => response.json()),
    enabled: !!stationId,
  })
  const station = stationQuery.data?.stopTimes[0].place ?? {name: "Chargement…"}

  useEffect(() => {
    if (realtime) {
      const interval = setInterval(() => {
        setDatetime(dayjs())
      }, 5000)
      return () => clearInterval(interval)
      }
  }, [realtime])

  return (
    <div className="Station">
      <header className="App-header">
        <h1>Horaires en gare de {station.name}</h1>
      </header>

      <main>
        <DateTimeSelector datetime={datetime} setDatetime={setDatetime} realtime={realtime} setRealtime={setRealtime} />
        {/*<TripsFilter />*/}
        <TrainsTable station={station} datetime={datetime} realtime={realtime} tableType="departures" />
        <TrainsTable station={station} datetime={datetime} realtime={realtime} tableType="arrivals" />
      </main>
    </div>
  )
}

export default Station;
